#
# spec file for package python-azure-ai-ml
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-azure-ai-ml
Version:        1.13.0
Release:        2.2
Summary:        Microsoft Azure Machine Learning Client Library for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python
Source:         https://files.pythonhosted.org/packages/source/a/azure-ai-ml/azure-ai-ml-%{version}.tar.gz
Source1:        LICENSE.txt
BuildRequires:  %{python_module PyJWT}
BuildRequires:  %{python_module PyYAML >= 5.1.0}
BuildRequires:  %{python_module applicationinsights}
BuildRequires:  %{python_module azure-ai-nspkg >= 1.0.0}
BuildRequires:  %{python_module azure-common >= 1.1}
BuildRequires:  %{python_module azure-core >= 1.23.0}
BuildRequires:  %{python_module azure-identity}
BuildRequires:  %{python_module azure-mgmt-core >= 1.3.0}
BuildRequires:  %{python_module azure-storage-blob >= 12.10.0}
BuildRequires:  %{python_module azure-storage-file-datalake}
BuildRequires:  %{python_module azure-storage-file-share}
BuildRequires:  %{python_module colorama < 0.5.0}
BuildRequires:  %{python_module docker}
BuildRequires:  %{python_module isodate}
BuildRequires:  %{python_module jsonschema >= 4.0.0}
BuildRequires:  %{python_module marshmallow >= 3.5}
BuildRequires:  %{python_module msrest >= 0.6.18}
BuildRequires:  %{python_module opencensus-ext-azure < 2.0.0}
BuildRequires:  %{python_module pathspec >= 0.9.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pydash >= 6.0.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module strictyaml < 2.0.0}
BuildRequires:  %{python_module tqdm < 5.0.0}
BuildRequires:  %{python_module typing-extensions >= 4.0.1}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-PyJWT < 3.0.0
Requires:       python-PyYAML >= 5.1.0
Requires:       python-applicationinsights <= 0.11.10
Requires:       python-azure-ai-nspkg >= 1.0.0
Requires:       python-azure-common >= 1.1
Requires:       python-azure-core >= 1.23.0
Requires:       python-azure-identity
Requires:       python-azure-mgmt-core >= 1.3.0
Requires:       python-azure-storage-blob >= 12.10.0
Requires:       python-azure-storage-file-datalake
Requires:       python-azure-storage-file-share
Requires:       python-colorama
Requires:       python-docker
Requires:       python-isodate
Requires:       python-jsonschema >= 4.0.0
Requires:       python-marshmallow >= 3.5
Requires:       python-msrest >= 0.6.18
Requires:       python-pathspec >= 0.9.0
Requires:       python-pydash
Requires:       python-strictyaml
Requires:       python-tqdm
Requires:       python-typing-extensions >= 4.0.1
Conflicts:      python-azure-sdk <= 2.0.0
Suggests:       python-mldesigner
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-azure-ai-ml < 1.13.0
%endif
BuildArch:      noarch
%python_subpackages

%description
We are excited to introduce the public preview of Azure Machine Learning Python
SDK v2. The Python SDK v2 introduces new SDK capabilities like standalone local
jobs, reusable components for pipelines and managed online/batch inferencing.
Python SDK v2 allows you to move from simple to complex tasks easily and
incrementally. This is enabled by using a common object model which brings
concept reuse and consistency of actions across various tasks. The SDK v2 shares
its foundation with the CLI v2 which is currently in also in public preview.

This package has been tested with Python 3.6, 3.7, 3.8, 3.9 and 3.10.

%prep
%setup -q -n azure-ai-ml-%{version}

%build
install -m 644 %{SOURCE1} %{_builddir}/azure-ai-ml-%{version}
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/azure/ai/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/ai/__pycache__
rm -rf %{buildroot}%{$python_sitelib}/azure/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/__pycache__
}

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE.txt
%{python_sitelib}/azure/ai/ml
%{python_sitelib}/azure_ai_ml-*.dist-info

%changelog
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Add Obsoletes for old python3 package on SLE-15
  + Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
* Tue Apr  2 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Remove duplicate python-rpm-macros and fdupes from BuildRequires
* Tue Jan 30 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.13.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon Nov 20 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.12.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Nov 14 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.12.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon Oct 16 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.11.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Oct  5 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.11.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Remove unzip package from BuildRequires
- Switch source archive format to TAR.GZ
* Wed Sep 20 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.10.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Sep  8 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.10.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Jun 13 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.8.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon May 22 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.7.2
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri May 19 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.7.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue May 16 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.7.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri May  5 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.6.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon Mar 27 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.5.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Feb  7 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.4.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update BuildRequires and Requires from setup.py
* Fri Jan 20 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.3.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Dec  6 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.2.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Nov 29 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.1.2
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Nov 16 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.1.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon Nov 14 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Tue Oct 11 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 1.0.0
